@@ -56,6 +56,7 @@ static std::unique_ptr <SelectionManager> selMgr = nullptr;
 static Display* xDisplay = nullptr;
 static Window xWindow;
 static Atom wmDeleteMessage;
+static XWMHints wmHints;
 static XSizeHints sizeHints;
 static Colormap colormap;
 
@@ -157,7 +158,8 @@ makeXWindow (const char* name, int width, int height, int px, int py,
 
    root = RootWindow (xDisplay, DefaultScreen (xDisplay));
 
-   if (!eglChooseConfig (eglDpy, eglAttrs, &config, 1, &numConfigs)) {
+   if (!eglChooseConfig (eglDpy, eglAttrs, &config, 1, &numConfigs))
+   {
       logE << "Couldn't get an EGL visual config" << std::endl;
       exit(1);
    }
@@ -165,7 +167,8 @@ makeXWindow (const char* name, int width, int height, int px, int py,
    assert (config);
    assert (numConfigs > 0);
 
-   if (!eglGetConfigAttrib (eglDpy, config, EGL_NATIVE_VISUAL_ID, &vid)) {
+   if (!eglGetConfigAttrib (eglDpy, config, EGL_NATIVE_VISUAL_ID, &vid))
+   {
       logE << "eglGetConfigAttrib() failed" << std::endl;
       exit (1);
    }
@@ -201,7 +204,6 @@ makeXWindow (const char* name, int width, int height, int px, int py,
       classHint.res_name = (char *)opts.name;
       classHint.res_class = (char *)"Zutty";
 
-      XWMHints wmHints;
       wmHints.input = true;
       wmHints.initial_state = NormalState;
       wmHints.flags = InputHint | StateHint;
@@ -1195,6 +1197,21 @@ handleOsc (int cmd, const std::string& arg)
    }
 }
 
+static void
+handleBell ()
+{
+   if (opts.bellIsAudible)
+   {
+      XBell (xDisplay, 0);
+   }
+
+   if (opts.bellIsUrgent)
+   {
+      wmHints.flags |= XUrgencyHint;
+      XSetWMHints (xDisplay, xWindow, &wmHints);
+   }
+}
+
 static void
 printGLInfo (EGLDisplay eglDpy)
 {
@@ -1241,7 +1258,7 @@ static int
 handleXError (Display* dpy, XErrorEvent* ev)
 {
    logE << "Exiting on received X error event:" << std::endl;
-   XmuPrintDefaultErrorMessage(dpy, ev, stdout);
+   XmuPrintDefaultErrorMessage (dpy, ev, stdout);
    fflush (stdout);
 
    renderer = nullptr; // ~Renderer () shuts down renderer thread
@@ -1439,6 +1456,8 @@ main (int argc, char* argv[])
       {
          if (!eglMakeCurrent (eglDpy, eglSurface, eglSurface, eglCtx))
             throw std::runtime_error ("Error: eglMakeCurrent() failed");
+         if (!eglSwapInterval (eglDpy, 0))
+            throw std::runtime_error ("Error: eglSwapInterval() failed");
          if (opts.glinfo)
             printGLInfo (eglDpy);
       },
@@ -1455,7 +1474,7 @@ main (int argc, char* argv[])
    vt->setRefreshHandler ([] (const zutty::Frame& f) { renderer->update (f); });
    vt->setOscHandler ([] (int cmd, const std::string& arg)
                       { handleOsc (cmd, arg); });
-   vt->setBellHandler ([] () { XBell (xDisplay, 0); });
+   vt->setBellHandler ([] () { handleBell (); });
 
    // We might not get a ConfigureNotify event when the window first appears:
    vt->resize (winWidth, winHeight);
