@@ -297,6 +297,7 @@ namespace zutty
 
       void csi_ecma48_SL (); // Shift Left
       void csi_ecma48_SR (); // Shift Right
+      void csi_DECSCUSR ();  // Set cursor style
 
       void csi_priDA ();     // Device Attributes (Primary)
       void csi_secDA ();     // Device Attributes (Secondary)
@@ -306,7 +307,8 @@ namespace zutty
       void handle_OSC ();    // Operating System Command
       void csiq_DECSCL ();   // DEC Set Compatibility Level
       void csi_XTWINOPS ();  // Xterm window operations
-      void csi_XTMODKEYS (); // Xterm key modifier options
+      void csi_XTMODKEYS (); // Xterm set/reset key modifier options
+      void csi_XTQMODKEYS ();// Xterm query key modifier options
 
       void dcs_DECRQSS (const std::string&); // DEC Request Status String
 
@@ -370,6 +372,8 @@ namespace zutty
       // Terminal state - N.B.: keep resetTerminal () in sync with this!
 
       bool showCursorMode = true;
+      using CursorStyle = CharVdev::Cursor::Style;
+      CursorStyle cursorStyle = CursorStyle::filled_block;
       bool altScreenBufferMode = false;
       bool autoWrapMode = true;
       bool autoNewlineMode = false;
